/*******************************************************************************
 * Copyright (c) 2000, 2004 QNX Software Systems and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     QNX Software Systems - Initial API and implementation
 *******************************************************************************/

package generic;

import java.io.IOException;

import org.eclipse.cdt.core.AbstractCExtension;
import org.eclipse.cdt.core.IBinaryParser;
import org.eclipse.core.runtime.IPath;

/**
 */
public class GenericBinaryParser extends AbstractCExtension implements IBinaryParser {

	/* (non-Javadoc)
	 * @see org.eclipse.cdt.core.IBinaryParser#getBinary(byte[], org.eclipse.core.runtime.IPath)
	 */
	public IBinaryFile getBinary(byte[] hints, IPath path) throws IOException {
		return getBinary(path);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.cdt.core.IBinaryParser#getBinary(org.eclipse.core.runtime.IPath)
	 */
	public IBinaryFile getBinary(IPath path) throws IOException {
		String ext = path.getFileExtension();
		if (ext != null) {
			if (ext.equals("exe")) {
				return new GenericBinaryExecutable(this, path);
			} else if (ext.equals("o") || ext.equals("obj")) {
				return new GenericBinaryObject(this, path);
			} else if (ext.equals("dll") || ext.equals("so")) {
				return new GenericBinarySharedLib(this, path);
			} else if (ext.equals("a")) {
				return new GenericBinaryArchive(this, path);
			}
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.cdt.core.IBinaryParser#getFormat()
	 */
	public String getFormat() {
		return "Generic";
	}

	/* (non-Javadoc)
	 * @see org.eclipse.cdt.core.IBinaryParser#isBinary(byte[], org.eclipse.core.runtime.IPath)
	 */
	public boolean isBinary(byte[] hints, IPath path) {
		String ext = path.getFileExtension();
		if (ext != null) {
			if (ext.equals("exe")) {
				return true;
			} else if (ext.equals("o") || ext.equals("obj")) {
				return true;
			} else if (ext.equals("dll") || ext.equals("so")) {
				return true;
			} else if (ext.equals("a")) {
				return true;
			}
		}
		return false;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.cdt.core.IBinaryParser#getHintBufferSize()
	 */
	public int getHintBufferSize() {
		return 0;
	}

}
